@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.024
+This document describes Attean::API::Iterator version 0.025
 
 =head1 DESCRIPTION
 
@@ -94,10 +94,9 @@ elements from the referent.
 
 =cut
 
-package Attean::API::Iterator 0.024 {
+package Attean::API::Iterator 0.025 {
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
-	use Role::Tiny;
 	use Carp qw(confess);
 
 	use Moo::Role;
@@ -112,30 +111,30 @@ package Attean::API::Iterator 0.024 {
 		my $args	= shift;
 		$self->$orig($args);
 		my $role	= $self->item_type;
-		if (Role::Tiny->is_role($role)) {
+		if (Moo::Role->is_role($role)) {
 			my $check	= sub {
 				my $check = shift;
-				return ($role eq $check or Role::Tiny::does_role($role, $check));
+				return ($role eq $check or Moo::Role::does_role($role, $check));
 			};
 			if ($check->('Attean::API::Quad')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::QuadIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::QuadIterator');
 			} elsif ($check->('Attean::API::Triple')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TripleIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::TripleIterator');
 			} elsif ($check->('Attean::API::TripleOrQuad')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
 			} elsif ($check->('Attean::API::Result')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultIterator');
 				my $vars	= $args->{variables} // confess "Construction of a Attean::API::ResultIterator must include a variables list";
 				$self->variables($vars);
 			} elsif ($check->('Attean::API::Term')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TermIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::TermIterator');
 			} elsif ($check->('Attean::API::ResultOrTerm')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
 				$self->variables($args->{variables} || []);
 			}
 
 			if ($self->does('Attean::API::RepeatableIterator') and $check->('Attean::API::Binding')) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
 			}
 		}
 	};
@@ -277,7 +276,7 @@ Print each item as it is consumed (with the string generated by C<< as_string >>
 	}
 }
 
-package Attean::API::RepeatableIterator 0.024 {
+package Attean::API::RepeatableIterator 0.025 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -313,7 +312,7 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.024 {
+package Attean::API::ResultOrTermIterator 0.025 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef Str);
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
@@ -351,7 +350,7 @@ package Attean::API::ResultOrTermIterator 0.024 {
 	};
 }
 
-package Attean::API::StatementIterator 0.024 {
+package Attean::API::StatementIterator 0.025 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	requires 'variables';
@@ -386,7 +385,7 @@ package Attean::API::StatementIterator 0.024 {
 	}
 }
 
-package Attean::API::TripleIterator 0.024 {
+package Attean::API::TripleIterator 0.025 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -402,7 +401,7 @@ package Attean::API::TripleIterator 0.024 {
 	}
 }
 
-package Attean::API::QuadIterator 0.024 {
+package Attean::API::QuadIterator 0.025 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -412,7 +411,7 @@ package Attean::API::QuadIterator 0.024 {
 	}
 }
 
-package Attean::API::MixedStatementIterator 0.024 {
+package Attean::API::MixedStatementIterator 0.025 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	sub as_quads {
@@ -425,7 +424,7 @@ package Attean::API::MixedStatementIterator 0.024 {
 	}
 }
 
-package Attean::API::ResultIterator 0.024 {
+package Attean::API::ResultIterator 0.025 {
 	use Types::Standard qw(Str ArrayRef);
 
 	use Moo::Role;
@@ -450,7 +449,7 @@ package Attean::API::ResultIterator 0.024 {
 	}
 }
 
-package Attean::API::TermIterator 0.024 {
+package Attean::API::TermIterator 0.025 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
