@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.024
+This document describes Attean::API::Term version 0.025
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ Returns a string serialization of the term.
 
 =cut
 
-package Attean::API::Term 0.024 {
+package Attean::API::Term 0.025 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
@@ -105,7 +105,7 @@ Returns true if the term has a true SPARQL "effective boolean value", false othe
 	}
 }
 
-package Attean::API::Literal 0.024 {
+package Attean::API::Literal 0.025 {
 	use IRI;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Maybe Str ConsumerOf);
@@ -151,9 +151,9 @@ package Attean::API::Literal 0.024 {
 		if (my $dt = $self->datatype) {
 			my $type	= $dt->value;
 			if ($type =~ qr<^http://www[.]w3[.]org/2001/XMLSchema#(?:integer|decimal|float|double|non(?:Positive|Negative)Integer|(?:positive|negative)Integer|long|int|short|byte|unsigned(?:Long|Int|Short|Byte))$>) {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::NumericLiteral');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::NumericLiteral');
 			} elsif ($type eq 'http://www.w3.org/2001/XMLSchema#dateTime') {
-				Role::Tiny->apply_roles_to_object($self, 'Attean::API::DateTimeLiteral');
+				Moo::Role->apply_roles_to_object($self, 'Attean::API::DateTimeLiteral');
 			}
 		}
 	};
@@ -289,7 +289,7 @@ package Attean::API::Literal 0.024 {
 	};
 }
 
-package Attean::API::DateTimeLiteral 0.024 {
+package Attean::API::DateTimeLiteral 0.025 {
 	use DateTime::Format::W3CDTF;
 
 	use Moo::Role;
@@ -301,12 +301,12 @@ package Attean::API::DateTimeLiteral 0.024 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.024 {
+package Attean::API::CanonicalizingLiteral 0.025 {
 	use Moo::Role;
 	requires 'canonicalized_term';
 }
 
-package Attean::API::NumericLiteral 0.024 {
+package Attean::API::NumericLiteral 0.025 {
 	use Scalar::Util qw(blessed looks_like_number);
 
 	use Moo::Role;
@@ -497,7 +497,7 @@ package Attean::API::NumericLiteral 0.024 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.024 {
+package Attean::API::Blank 0.025 {
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -523,7 +523,7 @@ package Attean::API::Blank 0.024 {
 	}
 }
 
-package Attean::API::IRI 0.024 {
+package Attean::API::IRI 0.025 {
 	use IRI;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
